@@ -112,9 +112,10 @@ var assignOperatorScenarios = []expressionScenario{
 		},
 	},
 	{
-		description: "Update selected results",
-		document:    `{a: {b: apple, c: cactus}}`,
-		expression:  `(.a[] | select(. == "apple")) = "frog"`,
+		description:    "Update deeply selected results",
+		subdescription: "Note that the LHS is wrapped in brackets! This is to ensure we dont first filter out the yaml and then update the snippet.",
+		document:       `{a: {b: apple, c: cactus}}`,
+		expression:     `(.a[] | select(. == "apple")) = "frog"`,
 		expected: []string{
 			"D0, P[], (doc)::{a: {b: frog, c: cactus}}\n",
 		},
